#!/usr/bin/env node

'use strict';

const dns = require('dns');
const got = require('got');
const stafo = require('stafo');
const chalk = require('chalk');
const ora = require('ora');
const logUpdate = require('log-update');
const updateNotifier = require('update-notifier');
const pkg = require('./package.json');

updateNotifier({pkg}).notify();

const spinner = ora();

const arg = process.argv[2];
const pre = `${chalk.bold.cyan('›')} `;

dns.lookup('github.com', err => {
	if (err) {
		logUpdate();
		console.log(`${chalk.bold.red('›')} ${chalk.dim('Please check your internet connection')}\n`);
		process.exit(1);
	}
});

if (!arg || arg === '-h') {
	console.log(`
 ${chalk.cyan('Usage   :')} stafo <${chalk.bold('username/repository')}>

 ${chalk.cyan('Example :')} stafo CodeDotJS/kote   ${chalk.dim('[user]')}
	   stafo facebook/reactjs ${chalk.dim('[organization]')}
	`);
}

if (arg) {
	logUpdate();
	spinner.start();
	spinner.text = chalk.dim(`Fetching stars and forks on ${chalk.bold(arg)}`);
	got(`https://github.com/${arg}`).then(() => {
		stafo.repo(arg).then(user => {
			const inf = [];
			const repoCount = (prefix, key) => {
				if (user[key]) {
					inf.push(`${prefix} : ${user[key]}`);
				}
			};
			logUpdate();
			repoCount(`${pre} Stars`, 'star');
			repoCount(`${pre} Forks`, 'fork');
			console.log(inf.join('\n'));
			console.log();
			spinner.stop();
		});
	}).catch(err => {
		if (err) {
			logUpdate(`\n› ${arg.split('/')[1]} is not available on Github\n`);
			spinner.stop();
		}
	});
}
